@@ -1,3 +1,4 @@
+
 /***************************************************************
 * L&L - Labyrinths & Legends
 * Copyright (c) 1993-2008 YOSHIMURA Tomohiko All rights reserved.
@@ -25,7 +26,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: GameMusic.cpp,v 1.12 2008/09/19 21:15:37 bowkenken Exp $
+* $Id: GameMusic.cpp,v 1.20 2008/10/06 23:03:53 bowkenken Exp $
 ***************************************************************/
 
 ////////////////////////////////////////////////////////////////
@@ -108,7 +109,7 @@ GameMusic::~GameMusic()
 void GameMusic::init()
 {
 #ifdef	HAVE_SDL_SDL_H
-	SDL_Init( SDL_INIT_AUDIO );
+	SDL_Init( SDL_INIT_VIDEO | SDL_INIT_AUDIO | SDL_INIT_JOYSTICK );
 #endif
 
 #ifdef	HAVE_SDL_SDL_MIXER_H
@@ -178,6 +179,11 @@ void GameMusic::init()
 
 	initLsMusic( &lsBattleBoss, "battle/boss/" );
 
+	// last boss
+
+	initLsMusic( &lsLastBoss, "dungeon/last" );
+	initLsMusic( &lsBattleLastBoss, "battle/boss/last" );
+
 	// ME
 
 	for( long i = 0; i < ME_KIND_MAX_N; i++ )
@@ -253,6 +259,16 @@ void GameMusic::playScene()
 	case SCENE_N_BATTLE_BOSS:
 		play( MUSIC_KIND_BATTLE_BOSS );
 		break;
+	case SCENE_N_LAST_BOSS:
+		playLastScene();
+		break;
+	case SCENE_N_GAME_OVER:
+		break;
+	case SCENE_N_GAME_OVER_WAIT:
+		break;
+	case SCENE_N_GAME_OVER_END:
+		play( MUSIC_KIND_GAME_OVER );
+		break;
 	case SCENE_N_ENDING:
 		break;
 	case SCENE_N_ENDING_EPILOGUE:
@@ -262,13 +278,6 @@ void GameMusic::playScene()
 		break;
 	case SCENE_N_ENDING_END:
 		break;
-	case SCENE_N_GAME_OVER:
-		break;
-	case SCENE_N_GAME_OVER_WAIT:
-		break;
-	case SCENE_N_GAME_OVER_END:
-		play( MUSIC_KIND_GAME_OVER );
-		break;
 	case SCENE_N_SEL_MBR_GRAPH:
 		break;
 	case SCENE_N_MAX_N:
@@ -276,6 +285,65 @@ void GameMusic::playScene()
 	}
 }
 
+////////////////////////////////////////////////////////////////
+// 饹ܥΥ˹礻 BGM κ
+////////////////////////////////////////////////////////////////
+
+void GameMusic::playLastScene()
+{
+	switch( get_last_scene() ){
+	case LAST_SCENE_N_NULL:
+		break;
+	case LAST_SCENE_N_ENTER:
+		play( MUSIC_KIND_LAST_BOSS );
+		break;
+	case LAST_SCENE_N_ENCOUNTER:
+	case LAST_SCENE_N_ENCOUNTER_CUT_IN:
+	case LAST_SCENE_N_ENCOUNTER_WORDS:
+	case LAST_SCENE_N_ENCOUNTER_CUT_OUT:
+	case LAST_SCENE_N_ENCOUNTER_CUT_END:
+	case LAST_SCENE_N_EXEL:
+	case LAST_SCENE_N_EXEL_ENTER:
+	case LAST_SCENE_N_EXEL_CUT_IN:
+	case LAST_SCENE_N_EXEL_WORDS:
+	case LAST_SCENE_N_EXEL_CUT_OUT:
+	case LAST_SCENE_N_EXEL_CUT_END:
+	case LAST_SCENE_N_EXEL_HYPER:
+		break;
+	case LAST_SCENE_N_EXEL_BATTLE:
+		play( MUSIC_KIND_BATTLE_BOSS );
+		break;
+	case LAST_SCENE_N_EXEL_DIE:
+		play( MUSIC_KIND_LAST_BOSS );
+		break;
+	case LAST_SCENE_N_EXELER:
+	case LAST_SCENE_N_EXELER_CUT_IN:
+	case LAST_SCENE_N_EXELER_WORDS:
+	case LAST_SCENE_N_EXELER_CUT_OUT:
+	case LAST_SCENE_N_EXELER_CUT_END:
+	case LAST_SCENE_N_EXELER_ENTER:
+	case LAST_SCENE_N_EXELER_HYPER:
+		break;
+	case LAST_SCENE_N_EXELER_BATTLE:
+		play( MUSIC_KIND_BATTLE_BOSS );
+		break;
+	case LAST_SCENE_N_EXELER_DIE:
+		play( MUSIC_KIND_LAST_BOSS );
+		break;
+	case LAST_SCENE_N_XEX:
+	case LAST_SCENE_N_XEX_CUT_IN:
+	case LAST_SCENE_N_XEX_WORDS:
+	case LAST_SCENE_N_XEX_CUT_OUT:
+		break;
+	case LAST_SCENE_N_XEX_CUT_END:
+		play( MUSIC_KIND_BATTLE_LAST_BOSS );
+		break;
+	case LAST_SCENE_N_END:
+	case LAST_SCENE_N_MAX_N:
+		break;
+	}
+}
+
 ////////////////////////////////////////////////////////////////
 // BGM κ
 // music_kind_t kind : BGM μ
@@ -308,12 +376,18 @@ void GameMusic::play( music_kind_t kind, long idx )
 	case MUSIC_KIND_DUN:
 		playDun( idx );
 		break;
+	case MUSIC_KIND_LAST_BOSS:
+		playLastBoss( idx );
+		break;
 	case MUSIC_KIND_BATTLE:
 		playBattle( idx );
 		break;
 	case MUSIC_KIND_BATTLE_BOSS:
 		playBattleBoss( idx );
 		break;
+	case MUSIC_KIND_BATTLE_LAST_BOSS:
+		playBattleLastBoss( idx );
+		break;
 	case MUSIC_KIND_EFFECT:
 		playEffect( idx );
 		break;
@@ -444,6 +518,19 @@ WSCstring GameMusic::playDun( long idx )
 	return playRandm( lsDun[idx].next );
 }
 
+////////////////////////////////////////////////////////////////
+// 饹ܥ BGM κ
+// long idx : BGM ꥹȤΥǥå
+// return : BGM եΥѥ
+////////////////////////////////////////////////////////////////
+
+WSCstring GameMusic::playLastBoss( long idx )
+{
+	setCurrent( MUSIC_KIND_LAST_BOSS, idx );
+
+	return playRandm( lsLastBoss.next );
+}
+
 ////////////////////////////////////////////////////////////////
 // Ʈ BGM κ
 // long idx : BGM ꥹȤΥǥå
@@ -484,6 +571,19 @@ WSCstring GameMusic::playBattleBoss( long idx )
 	return playRandm( lsBattleBoss.next );
 }
 
+////////////////////////////////////////////////////////////////
+// 饹ܥ BGM κ
+// long idx : BGM ꥹȤΥǥå
+// return : BGM եΥѥ
+////////////////////////////////////////////////////////////////
+
+WSCstring GameMusic::playBattleLastBoss( long idx )
+{
+	setCurrent( MUSIC_KIND_BATTLE_LAST_BOSS, idx );
+
+	return playRandm( lsBattleLastBoss.next );
+}
+
 ////////////////////////////////////////////////////////////////
 // ME κ
 // long idx : BGM ꥹȤΥǥå
