@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: GraphConf.cpp,v 1.3 2008/01/11 09:13:16 bowkenken Exp $
+* $Id: GraphConf.cpp,v 1.4 2008/04/25 04:09:51 bowkenken Exp $
 ***************************************************************/
 
 ////////////////////////////////////////////////////////////////
@@ -171,6 +171,8 @@ bool GraphConf::setNum( GraphConfToken token, long n )
 	case GRAPH_CONF_TOKEN_PC_PATERN:
 	case GRAPH_CONF_TOKEN_MONSTER_PATERN:
 	case GRAPH_CONF_TOKEN_WALL_PATERN:
+	case GRAPH_CONF_TOKEN_TOWN_WALL_PATERN:
+	case GRAPH_CONF_TOKEN_DUNGEON_WALL_PATERN:
 	case GRAPH_CONF_TOKEN_DOOR_PATERN:
 	case GRAPH_CONF_TOKEN_SIGNBOARD_PATERN:
 		break;
@@ -220,6 +222,12 @@ bool GraphConf::setStr( GraphConfToken token, WSCstring str )
 	case GRAPH_CONF_TOKEN_WALL_PATERN:
 		wall_patern = str;
 		return true;
+	case GRAPH_CONF_TOKEN_TOWN_WALL_PATERN:
+		town_wall_patern = str;
+		return true;
+	case GRAPH_CONF_TOKEN_DUNGEON_WALL_PATERN:
+		dungeon_wall_patern = str;
+		return true;
 	case GRAPH_CONF_TOKEN_DOOR_PATERN:
 		door_patern = str;
 		return true;
@@ -259,6 +267,8 @@ long GraphConf::getNum( GraphConfToken token )
 	case GRAPH_CONF_TOKEN_PC_PATERN:
 	case GRAPH_CONF_TOKEN_MONSTER_PATERN:
 	case GRAPH_CONF_TOKEN_WALL_PATERN:
+	case GRAPH_CONF_TOKEN_TOWN_WALL_PATERN:
+	case GRAPH_CONF_TOKEN_DUNGEON_WALL_PATERN:
 	case GRAPH_CONF_TOKEN_DOOR_PATERN:
 	case GRAPH_CONF_TOKEN_SIGNBOARD_PATERN:
 		break;
@@ -300,6 +310,10 @@ WSCstring GraphConf::getStr( GraphConfToken token )
 		return monster_patern;
 	case GRAPH_CONF_TOKEN_WALL_PATERN:
 		return wall_patern;
+	case GRAPH_CONF_TOKEN_TOWN_WALL_PATERN:
+		return town_wall_patern;
+	case GRAPH_CONF_TOKEN_DUNGEON_WALL_PATERN:
+		return dungeon_wall_patern;
 	case GRAPH_CONF_TOKEN_DOOR_PATERN:
 		return door_patern;
 	case GRAPH_CONF_TOKEN_SIGNBOARD_PATERN:
