@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: GuiChrSheet.cpp,v 1.10 2008/09/16 07:43:13 bowkenken Exp $
+* $Id: GuiChrSheet.cpp,v 1.13 2008/10/09 07:36:54 bowkenken Exp $
 ***************************************************************/
 
 ////////////////////////////////////////////////////////////////
@@ -1771,7 +1771,7 @@ void GuiChrSheet::draw( mbr_t *org, mbr_t *mbr )
 #endif // D_GTK
 
 #ifdef D_MFC
-	DdxSheet();
+	DdxToSheet();
 #endif // D_MFC
 }
 
@@ -1800,7 +1800,7 @@ void GuiChrSheet::redraw()
 #endif // D_GTK
 
 #ifdef D_MFC
-	DdxSheet();
+	DdxToSheet();
 #endif // D_MFC
 }
 
@@ -1808,9 +1808,9 @@ void GuiChrSheet::redraw()
 // DDX ѿΤ
 ////////////////////////////////////////////////////////////////
 
-#ifdef D_MFC
-void GuiChrSheet::DdxSheet()
+void GuiChrSheet::DdxToSheet()
 {
+#ifdef D_MFC
 	if( mChrSheetWin == NULL )
 		return;
 
@@ -1821,7 +1821,8 @@ void GuiChrSheet::DdxSheet()
 	mChrSheetWin->m_Stat.m_StrNameEdit = mbrData->name;
 	mChrSheetWin->m_Stat.m_StrFace = mbrData->face.mnr;
 	mChrSheetWin->m_Stat.m_StrRace = get_race_str( &(mbrData->race) );
-	mChrSheetWin->m_Stat.m_StrRaceName = get_race_name( &(mbrData->race) );
+//@@@	mChrSheetWin->m_Stat.m_StrRaceName = get_race_name( &(mbrData->race) );
+	mChrSheetWin->m_Stat.m_StrRaceName = mbrData->race.name;
 	mChrSheetWin->m_Stat.m_StrSex = get_sex_name( mbrData->sex.cur );
 
 	//// HP/MP
@@ -2126,7 +2127,6 @@ void GuiChrSheet::DdxSheet()
 		sn_printf( s, 32, "%4ld", nMbrLev );
 		mChrSheetWin->m_Abl.m_StrLev[i] = s;
 
-		sn_printf( s, 32, "%4ld", nMbrLev );
 		mChrSheetWin->m_Abl.m_StrAddLev[i] = strAddLev;
 
 		sn_printf( s, 32, "%4ld",
@@ -2207,12 +2207,24 @@ void GuiChrSheet::DdxSheet()
 
 	INT_PTR res = mChrSheetWin->DoModal();
 
-	if( res == IDCANCEL )
-		*mbrData = *orgData;
-	if( !mChrSheetWin->m_FlagContinue )
+	if( !mChrSheetWin->m_FlagContinue ){
+		if( res == IDCANCEL )
+			*mbrData = *orgData;
+
 		gKey.setChar( '0' );
-}
+	}
 #endif // D_MFC
+}
+
+////////////////////////////////////////////////////////////////
+// DDX ѿι
+////////////////////////////////////////////////////////////////
+
+void GuiChrSheet::DdxFromSheet()
+{
+#ifdef D_MFC
+#endif // D_MFC
+}
 
 ////////////////////////////////////////////////////////////////
 // ¾ιܤɽ
@@ -2871,17 +2883,23 @@ void GuiChrSheet::prevChrClicked()
 
 bool GuiChrSheet::nameChanged()
 {
-#ifdef D_GTK
 	if( mbrData == NULL )
 		return false;
 	if( !chk_sel_data_n( DATA_N_NAME, get_mbr_data_edit_kind() ) )
 		return false;
 
+#ifdef D_GTK
 	str_nz_cpy( mbrData->name,
 			gtk_entry_get_text( GTK_ENTRY( mStatName ) ),
 			MBR_NAME_MAX_LEN );
 #endif // D_GTK
 
+#ifdef	D_MFC
+	str_nz_cpy( mbrData->name,
+			mChrSheetWin->m_Stat.m_StrNameEdit,
+			MBR_NAME_MAX_LEN );
+#endif //D_MFC
+
 	return true;
 }
 
@@ -2891,17 +2909,23 @@ bool GuiChrSheet::nameChanged()
 
 bool GuiChrSheet::faceChanged()
 {
-#ifdef D_GTK
 	if( mbrData == NULL )
 		return false;
 	if( !chk_sel_data_n( DATA_N_FACE, get_mbr_data_edit_kind() ) )
 		return false;
 
+#ifdef D_GTK
 	const gchar *s = gtk_entry_get_text( GTK_ENTRY( mStatFace ) );
 	if( s != NULL )
 		mbrData->face.mnr = s[0];
 #endif // D_GTK
 
+#ifdef	D_MFC
+	const char *s = mChrSheetWin->m_Stat.m_StrFace;
+	if( s != NULL )
+		mbrData->face.mnr = s[0];
+#endif //D_MFC
+
 	return true;
 }
 
@@ -2914,6 +2938,8 @@ bool GuiChrSheet::raceClicked()
 	if( !chk_sel_data_n( DATA_N_RACE_STR, get_mbr_data_edit_kind() ) )
 		return false;
 
+	DdxFromSheet();
+
 	set_data_n( DATA_N_RACE_STR );
 	gKey.setChar( '\n' );
 	return true;
@@ -2925,17 +2951,23 @@ bool GuiChrSheet::raceClicked()
 
 bool GuiChrSheet::raceNameChanged()
 {
-#ifdef D_GTK
 	if( mbrData == NULL )
 		return false;
 	if( !chk_sel_data_n( DATA_N_RACE_NAME, get_mbr_data_edit_kind() ) )
 		return false;
 
+#ifdef D_GTK
 	str_nz_cpy( mbrData->race.name,
 			gtk_entry_get_text( GTK_ENTRY( mStatRaceName ) ),
 			RACE_NAME_MAX_LEN );
 #endif // D_GTK
 
+#ifdef	D_MFC
+	str_nz_cpy( mbrData->race.name,
+			mChrSheetWin->m_Stat.m_StrRaceName,
+			RACE_NAME_MAX_LEN );
+#endif //D_MFC
+
 	return true;
 }
 
@@ -2948,6 +2980,8 @@ bool GuiChrSheet::sexClicked()
 	if( !chk_sel_data_n( DATA_N_SEX, get_mbr_data_edit_kind() ) )
 		return false;
 
+	DdxFromSheet();
+
 	set_data_n( DATA_N_SEX );
 	gKey.setChar( '\n' );
 	return true;
@@ -2962,6 +2996,8 @@ bool GuiChrSheet::tileClicked()
 	if( !chk_sel_data_n( DATA_N_GRAPH_FILE, get_mbr_data_edit_kind() ) )
 		return false;
 
+	DdxFromSheet();
+
 	set_data_n( DATA_N_GRAPH_FILE );
 	gKey.setChar( '\n' );
 	return true;
@@ -2977,6 +3013,8 @@ bool GuiChrSheet::classClicked()
 	if( !chk_sel_data_n( DATA_N_CLASS, get_mbr_data_edit_kind() ) )
 		return false;
 
+	DdxFromSheet();
+
 	set_data_n( DATA_N_CLASS );
 	gKey.setChar( '\n' );
 	return true;
@@ -2994,6 +3032,8 @@ bool GuiChrSheet::itemClicked( long n )
 	if( !chk_sel_data_n( data, get_mbr_data_edit_kind() ) )
 		return false;
 
+	DdxFromSheet();
+
 	set_data_n( data );
 	gKey.setChar( '\n' );
 	return true;
@@ -3011,6 +3051,8 @@ bool GuiChrSheet::equipClicked( long n )
 	if( !chk_sel_data_n( data, get_mbr_data_edit_kind() ) )
 		return false;
 
+	DdxFromSheet();
+
 	set_data_n( data );
 	gKey.setChar( '\n' );
 	return true;
