@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: GuiInputString.h,v 1.13 2008/05/02 12:38:07 bowkenken Exp $
+* $Id: GuiInputString.h,v 1.14 2008/08/17 11:51:30 bowkenken Exp $
 ***************************************************************/
 
 #ifndef GUI_INPUT_STRING_H
@@ -72,20 +72,8 @@ public:
 	//////// ѥ֥åСؿ ////////
 public:
 
-	GuiInputString()
-	{
-#ifdef D_GTK
-		mWin = NULL;
-#endif // D_GTK
-
-#ifdef D_MFC
-		mInpStrWin = NULL;
-#endif // D_MFC
-	}
-	~GuiInputString()
-	{
-	}
-
+	GuiInputString();
+	~GuiInputString();
 	void init();
 	void destroy();
 
