@@ -25,19 +25,15 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: Key.cpp,v 1.13 2008/01/11 09:13:16 bowkenken Exp $
+* $Id: Key.cpp,v 1.17 2008/09/27 08:48:04 bowkenken Exp $
 ***************************************************************/
 
-#include "gmain.h"
-#include "dun.h"
-#include "replay.h"
-#include "menu.h"
-#include "dun-prot.h"
-#include "replay-prot.h"
-#include "mmenu-prot.h"
+////////////////////////////////////////////////////////////////
+// GUI Ͻ
+////////////////////////////////////////////////////////////////
 
-#include "Key.h"
-#include "GlobalVar.h"
+#define	KEY_CPP
+#include "inc.h"
 
 ////////////////////////////////////////////////////////////////
 // WideStudio ΥХ롦եåΥϥɥ
@@ -696,16 +692,17 @@ void Key::setString( WSCstring s, bool flagCheckClear )
 	if( flagCheckClear && g_flg_clr_key_buf ){
 		static long gPreChar = -1;
 
-		if( get_key_buf_char() == '\0' )
-			gPreChar = -1;
-
-		for( int i = 0; i < s.getChars(); i++ ){
-			if( s[i] == gPreChar ){
-				s.deleteChar( i );
-				i--;
-			} else {
-				gPreChar = s[i];
+		if( chk_key_buf() ){
+			for( int i = 0; i < s.getChars(); i++ ){
+				if( s[i] == gPreChar ){
+					s.deleteChar( i );
+					i--;
+				} else {
+					gPreChar = s[i];
+				}
 			}
+		} else {
+			gPreChar = -1;
 		}
 	}
 
@@ -774,18 +771,34 @@ bool Key::chkBuf()
 	return( buf.getChars() > 0 );
 }
 
+////////////////////////////////////////////////////////////////
+// ư
+// long mapX : X ư
+// long mapY : Y ư
+// return : ưǤ?
+////////////////////////////////////////////////////////////////
+
+bool Key::moveCrsrRel( long mapX, long mapY )
+{
+	pos_t *crsr = get_crsr();
+	if( crsr == NULL )
+		return false;
+
+	mapX = crsr->x + mapX;
+	mapY = crsr->y + mapY;
+
+	return gKey.moveCrsrAbs( mapX, mapY );
+}
+
 ////////////////////////////////////////////////////////////////
 // кɸꤷƥư
 // long mapX : X ɸ
 // long mapY : Y ɸ
-// return : ꤷɸޤǰư줿
+// return : ꤷɸޤǰư줿?
 ////////////////////////////////////////////////////////////////
 
 bool Key::moveCrsrAbs( long mapX, long mapY )
 {
-	if( !clip_pos( mapX, mapY ) )
-		return false;
-
 	if( !g_flg_gui )
 		return true;
 	if( get_flg_play_replay() )
@@ -794,11 +807,114 @@ bool Key::moveCrsrAbs( long mapX, long mapY )
 	pos_t *crsr = get_crsr();
 	if( crsr == NULL )
 		return false;
+
+	if( !clip_x( mapX ) )
+		mapX = crsr->x;
+	if( !clip_y( mapY ) )
+		mapY = crsr->y;
+
 	if( (crsr->x == mapX) && (crsr->y == mapY) )
 		return true;
 
 	crsr->x = mapX;
 	crsr->y = mapY;
+
+	//
+
+	long a = 1;
+#ifdef	D_MFC
+	a = 0;
+#endif	// D_MFC
+
+	pos_t *draw_gui = get_map_draw_pos_gui();
+	if( draw_gui != NULL ){
+		long w = gPcgDun.getScrollBarW();
+		long h = gPcgDun.getScrollBarH();
+		w /= gPcgDun.getTileSizeX( true );
+		h /= gPcgDun.getTileSizeY( true );
+
+		if( draw_gui->x > mapX )
+			draw_gui->x = mapX;
+		if( draw_gui->y > mapY )
+			draw_gui->y = mapY;
+		if( draw_gui->x < (mapX - w + a) )
+			draw_gui->x = (mapX - w + a);
+		if( draw_gui->y < (mapY - h + a) )
+			draw_gui->y = (mapY - h + a);
+	}
+
+	setString( "|", true );
+
+	return true;
+}
+
+////////////////////////////////////////////////////////////////
+// 뤹
+// long mapX : X ư
+// long mapY : Y ư
+// return : Ǥ?
+////////////////////////////////////////////////////////////////
+
+bool Key::scrollRel( long mapX, long mapY )
+{
+	pos_t *draw_gui = get_map_draw_pos_gui();
+	if( draw_gui == NULL )
+		return false;
+
+	mapX += draw_gui->x;
+	mapY += draw_gui->y;
+
+	return scrollAbs( mapX, mapY );
+}
+
+////////////////////////////////////////////////////////////////
+// кɸꤷƥ뤹
+// long mapX : X ɸ
+// long mapY : Y ɸ
+// return : ꤷɸޤǥ뤷줿?
+////////////////////////////////////////////////////////////////
+
+bool Key::scrollAbs( long mapX, long mapY )
+{
+	if( !g_flg_gui )
+		return true;
+	if( get_flg_play_replay() )
+		return true;
+
+	pos_t *draw_gui = get_map_draw_pos_gui();
+	if( draw_gui == NULL )
+		return false;
+
+	if( !clip_x( mapX ) )
+		mapX = draw_gui->x;
+	if( !clip_y( mapY ) )
+		mapY = draw_gui->y;
+
+	if( (draw_gui->x == mapX) && (draw_gui->y == mapY) )
+		return true;
+
+	draw_gui->x = mapX;
+	draw_gui->y = mapY;
+
+	//
+
+	pos_t *crsr = get_crsr();
+	if( crsr != NULL ){
+		long w = gPcgDun.getScrollBarW();
+		long h = gPcgDun.getScrollBarH();
+		w /= gPcgDun.getTileSizeX( true );
+		h /= gPcgDun.getTileSizeY( true );
+
+		if( crsr->x < mapX )
+			crsr->x = mapX;
+		if( crsr->y < mapY )
+			crsr->y = mapY;
+		if( crsr->x > (mapX + w - 1) )
+			crsr->x = (mapX + w - 1);
+		if( crsr->y > (mapY + h - 1) )
+			crsr->y = (mapY + h - 1);
+	}
+
 	setString( "|", true );
 
 	return true;
