@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: MouseMap.cpp,v 1.30 2008/05/05 12:43:59 bowkenken Exp $
+* $Id: MouseMap.cpp,v 1.33 2008/09/20 01:20:41 bowkenken Exp $
 ***************************************************************/
 
 #ifdef D_WS
@@ -43,8 +43,8 @@
 
 #ifdef D_MFC
 # include "xlnl-dows/stdafx.h"
-//# include "xlnl-dows/xlnl-dows.h"
-//# include "xlnl-dows/MainFrm.h"
+# include "xlnl-dows/xlnl-dows.h"
+# include "xlnl-dows/MainFrm.h"
 #endif // D_MFC
 
 #include "gmain.h"
@@ -425,6 +425,11 @@ void funcMotionClick(
 {
 	MouseMotion::MouseButtonN n = (MouseMotion::MouseButtonN)m;
 
+	if( get_scene() == SCENE_N_GAME_OVER_END ){
+		gKey.setChar( 'Q' - '@' );
+		return;
+	}
+
 	if( n < MouseMotion::nMouseButton0 )
 		return;
 	if( n >= MouseMotion::nMouseButtonMaxN )
@@ -457,9 +462,9 @@ print_msg( 0, "55555" );//@@@
 #else
 	if( chk_scene_group( SCENE_GROUP_N_SEL_GRAPH ) ){
 		if( n == MouseMotion::nMouseButtonL )
-			gKey.setString( "+" );
+			gSelMbrGraph->sel( nBgnX, nBgnY );
 		if( n == MouseMotion::nMouseButtonR )
-			gKey.setString( "0" );
+			gSelMbrGraph->cancel();
 	} else {
 		callFuncKey( FUNC_N_CLICK_0 + n );
 	}
@@ -488,10 +493,14 @@ void funcMotionDoubleClick(
 	if( n >= MouseMotion::nMouseButtonMaxN )
 		return;
 
-	if( n == MouseMotion::nMouseButtonL ){
-		unset_square_pos();
-
-		gKey.setChar( 'M' - '@' );
+	if( chk_scene_group( SCENE_GROUP_N_SEL_GRAPH ) ){
+		if( n == MouseMotion::nMouseButtonL )
+			gSelMbrGraph->ok();
+	} else {
+		if( n == MouseMotion::nMouseButtonL ){
+			unset_square_pos();
+			gKey.setChar( 'M' - '@' );
+		}
 	}
 }
 
