@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: MouseMotion.cpp,v 1.7 2008/09/21 02:37:46 bowkenken Exp $
+* $Id: MouseMotion.cpp,v 1.8 2008/09/27 08:48:04 bowkenken Exp $
 ***************************************************************/
 
 #include <stdlib.h>
@@ -33,6 +33,7 @@
 #include "draw.h"
 #include "draw-prot.h"
 #include "MouseMotion.h"
+#include "GlobalVar.h"
 
 ////////////////////////////////////////////////////////////////
 // 󥹥ȥ饯
@@ -379,6 +380,13 @@ bool MouseMotion::move( long x, long y )
 
 bool MouseMotion::point( long x, long y )
 {
+	long w = gPcgDun.getScrollBarW();
+	long h = gPcgDun.getScrollBarH();
+	if( x >= w + 16 )
+		return false;
+	if( y >= h + 16 )
+		return false;
+
 	// ݥ
 	if( pFuncPoint != NULL ){
 		(*pFuncPoint)( (MouseButtonN)0, 0, 0, x, y );
