@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: PcgDun.h,v 1.56 2008/09/08 01:21:04 bowkenken Exp $
+* $Id: PcgDun.h,v 1.61 2008/10/05 20:09:27 bowkenken Exp $
 ***************************************************************/
 
 #ifndef PCG_DUN_H
@@ -44,6 +44,7 @@
 
 #include "GraphConf.h"
 #include "DemoTitle.h"
+#include "DemoLastBoss.h"
 #include "DemoGameOver.h"
 #include "DemoEnding.h"
 #include "Pcg.h"
@@ -117,6 +118,7 @@ class PcgDun {
 public:
 	GraphConf *pGraphConf;
 	DemoTitle *pDemoTitle;
+	DemoLastBoss *pDemoLastBoss;
 	DemoGameOver *pDemoGameOver;
 	DemoEnding *pDemoEnding;
 
@@ -139,9 +141,13 @@ private:
 	// ΥѥΥꥹ
 	Pcg pcgFloorTown;
 	Pcg pcgFloorDun;
+	Pcg pcgFloorLast;
+	// 
+	Pcg pcgHole;
 	// ɤΥѥΥꥹ
 	Pcg pcgWallTown;
 	Pcg pcgWallDun;
+	Pcg pcgWallLast;
 	Pcg pcgStatue;
 	// ΥѥΥꥹ
 	Pcg pcgStreetlampOn;
@@ -153,6 +159,7 @@ private:
 	Pcg pcgStairsUpDun;
 	Pcg pcgStairsDownTown;
 	Pcg pcgStairsDownDun;
+	Pcg pcgStairsLastBoss;
 	// ɥΥѥΥꥹ
 	Pcg pcgDoorCloseTown;
 	Pcg pcgDoorCloseDun;
@@ -184,6 +191,7 @@ private:
 	// ɤΥѥ󡦥
 	WallPtnType nWallPtnTypeTown;
 	WallPtnType nWallPtnTypeDun;
+	WallPtnType nWallPtnTypeLast;
 
 	// 褹ɬפ륭饯Υޥå
 	bool bFlgUpdate[MAP_MAX_Y][MAP_MAX_X];
@@ -258,6 +266,7 @@ public:
 	~PcgDun();
 
 	void initTitle();
+	void initLastBoss();
 	void initGameOver();
 	void initEnding();
 	void init( GraphConf *cnf );
@@ -301,6 +310,7 @@ public:
 	void setFlgUpdateRequest( bool flg );
 
 	bool drawTitle();
+	bool drawLastBoss();
 	bool drawGameOver();
 	bool drawEnding();
 
@@ -331,6 +341,7 @@ public:
 private:
 /*
 	void initTitle();
+	void initLastBoss();
 	void initGameOver();
 	void initEnding();
 	void init( GraphConf *cnf );
@@ -384,6 +395,8 @@ private:
 	);
 	void drawTurn( bool flgForce = false );
 */
+	void drawTurnSub();
+	void drawTurnFlush();
 	bool drawSub( long mapX, long mapY, long mapW, long mapH );
 /*
 	void flush( long mapX, long mapY, long mapW, long mapH );
@@ -410,6 +423,7 @@ private:
 	bool getUpdateFlg( long mapX, long mapY );
 /*
 	bool drawTitle();
+	bool drawLastBoss();
 	bool drawGameOver();
 	bool drawEnding();
 */
@@ -418,8 +432,16 @@ private:
 	bool drawItemAll( long mapX, long mapY );
 	bool drawNull( long mapX, long mapY );
 	bool drawFloor( long mapX, long mapY );
+	bool drawHole( long mapX, long mapY );
 	bool drawObjFix( long mapX, long mapY, Pcg *lsTown, Pcg *lsDun );
-	Pcg *srchPcgLsMap( long mapX, long mapY, Pcg *lsTown, Pcg *lsDun );
+	Pcg *srchPcgLsMap(
+		long mapX, long mapY,
+		Pcg *lsTown, Pcg *lsDun
+	);
+	Pcg *srchPcgLsMapLast(
+		long mapX, long mapY,
+		Pcg *lsXX, Pcg *lsBone
+	);
 	bool drawWall( long mapX, long mapY );
 	bool drawWallTypeTile( long mapX, long mapY );
 	bool drawWallTypeA( long mapX, long mapY );
