@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: PcgDunTab.h,v 1.19 2008/05/13 00:53:05 bowkenken Exp $
+* $Id: PcgDunTab.h,v 1.23 2008/10/04 11:07:27 bowkenken Exp $
 ***************************************************************/
 
 #ifndef PCG_DUN_TAB_H
@@ -127,6 +127,38 @@ PcgTab gPcgTabFloorDun[] = {
 	},
 };
 
+PcgTab gPcgTabFloorLast[] = {
+	{
+		// 
+		MNSTR_KIND_NULL,
+		FACE_MJR_NULL, FACE_MNR_NULL,
+		100,
+		"floor/last/",
+	},
+	{
+		MNSTR_KIND_NULL,
+		FACE_MJR_NULL, FACE_MNR_NULL,
+		-1,
+		"",
+	},
+};
+
+PcgTab gPcgTabHole[] = {
+	{
+		// 
+		MNSTR_KIND_NULL,
+		FACE_MJR_NULL, FACE_MNR_NULL,
+		100,
+		"floor/hole/",
+	},
+	{
+		MNSTR_KIND_NULL,
+		FACE_MJR_NULL, FACE_MNR_NULL,
+		-1,
+		"",
+	},
+};
+
 PcgTab gPcgTabWallTown[] = {
 	{
 		// 
@@ -173,6 +205,22 @@ PcgTab gPcgTabWallDun[] = {
 	},
 };
 
+PcgTab gPcgTabWallLast[] = {
+	{
+		// 
+		MNSTR_KIND_NULL,
+		FACE_MJR_NULL, FACE_MNR_NULL,
+		100,
+		"wall/last/",
+	},
+	{
+		MNSTR_KIND_NULL,
+		FACE_MJR_NULL, FACE_MNR_NULL,
+		-1,
+		"",
+	},
+};
+
 PcgTab gPcgTabStatue[] = {
 	{
 		// 
@@ -301,6 +349,22 @@ PcgTab gPcgTabStairsDownDun[] = {
 	},
 };
 
+PcgTab gPcgTabStairsLastBoss[] = {
+	{
+		// 
+		MNSTR_KIND_NULL,
+		FACE_MJR_NULL, FACE_MNR_NULL,
+		100,
+		"stairs/down/last/",
+	},
+	{
+		MNSTR_KIND_NULL,
+		FACE_MJR_NULL, FACE_MNR_NULL,
+		-1,
+		"",
+	},
+};
+
 PcgTab gPcgTabDoorCloseTown[] = {
 	{
 		// 
@@ -1690,6 +1754,47 @@ PcgTab gPcgTabMnstr[] = {
 		100,
 		"character/monster/huge/gigantic_centipede/",
 	},
+	/* 饹ܥ */
+	{
+		MNSTR_KIND_EXEL,
+		FACE_MJR_NULL, FACE_MNR_NULL,
+		100,
+		"character/monster/devil/exel/",
+	},
+	{
+		MNSTR_KIND_EXELER,
+		FACE_MJR_NULL, FACE_MNR_NULL,
+		100,
+		"character/monster/devil/exeler/",
+	},
+	{
+		MNSTR_KIND_XEX,
+		FACE_MJR_NULL, FACE_MNR_NULL,
+		100,
+		"character/monster/devil/xex/",
+	},
+	/**/
+	{
+		MNSTR_KIND_NULL,
+		FACE_MJR_NULL, FACE_MNR_NULL,
+		-1,
+		"",
+	},
+};
+
+PcgTab gPcgTabMnstrHyper[] = {
+	{
+		MNSTR_KIND_EXEL,
+		FACE_MJR_NULL, FACE_MNR_NULL,
+		100,
+		"character/monster/devil/exel/hyper/",
+	},
+	{
+		MNSTR_KIND_EXELER,
+		FACE_MJR_NULL, FACE_MNR_NULL,
+		100,
+		"character/monster/devil/exeler/hyper/",
+	},
 	/**/
 	{
 		MNSTR_KIND_NULL,
