@@ -62,8 +62,15 @@ long	call_pcg_dun_get_chr_draw_bottom( chr_t *chr, bool_t flagPre );
 bool_t	call_pcg_dun_clip_win( long mapX, long mapY );
 bool_t	call_pcg_dun_clip_win_x( long mapX );
 bool_t	call_pcg_dun_clip_win_y( long mapY );
+void	call_demo_last_boss_reset( void );
+bool_t	call_demo_last_boss_check_done( void );
 void	call_game_music_play_scene( void );
 void	call_game_music_play( long kind, long idx );
+long	call_game_joystick_get_joy( void );
+void	call_game_joystick_sel_joy( long n );
+const char	*call_game_joystick_get_name( long n );
+long	call_game_joystick_get_kind( void );
+void	call_game_joystick_set_kind( long kind );
 void	call_gui_stat_redraw( void );
 void	call_gui_stat_draw( long n );
 void	call_win_pos_set(
