@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: chr.h,v 1.113 2008/09/16 07:42:41 bowkenken Exp $
+* $Id: chr.h,v 1.116 2008/10/07 00:41:05 bowkenken Exp $
 ***************************************************************/
 
 #ifndef	CHR_H
@@ -98,6 +98,7 @@ typedef unsigned long	flg_chr_t;
 #define	FLG_CHR_LIGHT	(1 << 11)	/* äƤ */
 #define	FLG_CHR_DARK	(1 << 12)	/* ǤäƤ */
 #define	FLG_CHR_MAGIC_PROTECT	(1 << 13)	/* ˡ路ʤ */
+#define	FLG_CHR_HYPER	(1 << 13)	/* 緿 */
 #define	FLG_CHR_CAN_DEL	(1 << 20)	/*  */
 #define	FLG_CHR_CAN_DISMISSAL	(1 << 21)	/* Խ */
 
@@ -598,6 +599,29 @@ typedef enum {
 	ATTITUDE_ENEMY,
 } attitude_t;
 
+/***************************************************************
+* 饯緿
+***************************************************************/
+
+/* NULL  PERFECT ʳϽ֤¤ѤƤOK */
+
+typedef enum {
+	/* 緿̵ */
+	HYPER_BOSS_NULL,
+	/* ̾ */
+	HYPER_BOSS_NORMAL,
+	/* 緿 */
+	HYPER_BOSS_NW,
+	/* 緿 */
+	HYPER_BOSS_SE,
+	/* 緿 */
+	HYPER_BOSS_NE,
+	/* 緿 */
+	HYPER_BOSS_SW,
+	/* 緿λ */
+	HYPER_BOSS_PERFECT,
+} hyper_boss_t;
+
 /***************************************************************
 * 
 ***************************************************************/
@@ -606,6 +630,11 @@ typedef struct {
 	/* ե饰 */
 	flg_work_t	flg;
 
+	/* 饯緿 */
+	hyper_boss_t	hyper_boss;
+	/* 饯緿ե饰 (GUI) */
+	bool_t	flg_hyper_boss;
+
 	/*  PC ޤƤ륭οͿ */
 	long	caught;
 
