@@ -123,6 +123,7 @@ void	draw_blast(
 	blast_t *p, char *str
 );
 void	draw_request( request_t *req );
+void	draw_words( const char *words );
 void	redraw_mbr_data( mbr_t *org, mbr_t *mbr, long page_n );
 void	draw_mbr_data_all( mbr_t *org, mbr_t *mbr, long page_n );
 void	draw_mbr_data_all_cui( mbr_t *org, mbr_t *mbr, long page_n );
@@ -160,6 +161,7 @@ void	reset_crsr( void );
 void	draw_crsr( void );
 void	draw_sub_crsr( void );
 pos_t	*get_map_draw_pos( void );
+pos_t	*get_map_draw_pos_gui( void );
 rate_t	get_vfx_wait( void );
 rate_t	set_vfx_wait( rate_t n );
 flg_vfx_mbr_t	get_flg_vfx_mbr( void );
@@ -167,6 +169,7 @@ flg_vfx_mbr_t	set_flg_vfx_mbr( flg_vfx_mbr_t flg );
 flg_vfx_mnstr_t	get_flg_vfx_mnstr( void );
 flg_vfx_mnstr_t	set_flg_vfx_mnstr( flg_vfx_mnstr_t flg );
 void	wait_clock( long frame );
+void	wait_frame( long frame );
 void	set_flg_break_key( bool_t flg_break );
 bool_t	chk_flg_break_key( void );
 long	read_char( long *p );
