@@ -1,6 +1,6 @@
 /***************************************************************
 * L&L - Labyrinths & Legends
-* Copyright (c) 1993-2007 YOSHIMURA Tomohiko All rights reserved.
+* Copyright (c) 1993-2008 YOSHIMURA Tomohiko All rights reserved.
 * 
 * Created by BowKenKen
 *   URL: https://sourceforge.jp/projects/lnl/
@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: draw.h,v 1.56 2007/06/11 09:41:02 bowkenken Exp $
+* $Id: draw.h,v 1.60 2008/09/25 12:23:02 bowkenken Exp $
 ***************************************************************/
 
 #ifndef	DRAW_H
@@ -175,6 +175,8 @@ typedef struct {
 * ե졼ࡦ졼
 ***************************************************************/
 
+#define	TIMER_FRAME	4
+
 #define	ANIM_FRAME_N	((long)(1.0 * 60.0))
 
 #define	ANIM_FRAME_N_BLAST_STD	((long)(0.5 * 60.0))
@@ -215,6 +217,13 @@ typedef unsigned long	flg_vfx_mnstr_t;
 #define	VFX_WAIT_MIN_N	1
 #define	VFX_WAIT_MAX_N	200
 
+/***************************************************************
+* ޥɡ
+***************************************************************/
+
+#define	CMD_KEY_IDLE	'|'
+#define	CMD_KEY_CONT_EXEC	','
+
 /***************************************************************
 * ơ֥
 ***************************************************************/
@@ -271,6 +280,7 @@ typedef enum {
 	DATA_N_STAT_SENSE_INVISIBLE,
 
 	DATA_N_STORE_LIGHT,
+	DATA_N_GRAPH_FILE,
 
 	DATA_N_LEV_LEFT,
 	DATA_N_EXP_LEFT,
