@@ -16,6 +16,7 @@ bool_t	clr_continue_exec_mode( void );
 char	*cb_menu_stairs( menu_t **pp, menu_t **dflt );
 char	*cb_menu_stairs_up( menu_t **pp, menu_t **dflt );
 char	*cb_menu_stairs_down( menu_t **pp, menu_t **dflt );
+char	*cb_menu_stairs_last_boss( menu_t **pp, menu_t **dflt );
 char	*cb_menu_srch( menu_t **pp, menu_t **dflt );
 char	*cb_menu_srch_init( menu_t **pp, menu_t **dflt );
 char	*cb_menu_srch_exec( menu_t **pp, menu_t **dflt );
@@ -37,6 +38,14 @@ long	menu_mbr_data(
 	mbr_t *org_p, long *page_n, data_n_t *data_n,
 	mbr_data_edit_kind_t edit_kind
 );
+long	menu_mbr_data_sub(
+	mbr_t *org_p, long *page_n, data_n_t *data_n,
+	mbr_data_edit_kind_t edit_kind
+);
+void	set_data_n( data_n_t data_n );
+long	get_mbr_data_page_n( void );
+void	set_mbr_data_page_n( long n );
+mbr_data_edit_kind_t	get_mbr_data_edit_kind( void );
 void	exec_menu_edit_mbr_data(
 	mbr_t *mbr, data_n_t n, long *mbr_dn, long *page_dn
 );
@@ -65,9 +74,9 @@ char	*cb_menu_crsr_move_mbr( menu_t **pp, menu_t **dflt );
 char	*menu_crsr_move_mbr_n( long mbr_n );
 char	*menu_crsr_move_mbr( mbr_t *mbr );
 char	*cb_menu_crsr_center( menu_t **pp, menu_t **dflt );
+void	chk_scroll( bool_t flg_gui );
 void	scroll_smooth( void );
 void	scroll_center( void );
-void	chk_scroll( bool_t flg_gui );
 void	scroll_half_page( void );
 void	move_crsr_mbr_trgt( mbr_t *mbr );
 char	*cb_menu_crsr_next_pos_mbr( menu_t **pp, menu_t **dflt );
@@ -151,6 +160,10 @@ char	*cb_menu_func( menu_t **pp, menu_t **dflt );
 char	*cb_menu_func_exec( menu_t **pp, menu_t **dflt );
 char	*cb_menu_func_edit( menu_t **pp, menu_t **dflt );
 char	*cb_menu_func_set_reg_macro( menu_t **pp, menu_t **dflt );
+char	*cb_menu_joystick_sel_n_init( menu_t **pp, menu_t **dflt );
+char	*cb_menu_joystick_sel_kind_init( menu_t **pp, menu_t **dflt );
+char	*cb_menu_joystick_sel_n( menu_t **pp, menu_t **dflt );
+char	*cb_menu_joystick_sel_kind( menu_t **pp, menu_t **dflt );
 char	*cb_menu_user( menu_t **pp, menu_t **dflt );
 void	clr_user_menu( void );
 void	add_user_menu( char *name, char *cmd );
@@ -162,10 +175,15 @@ char	*cb_menu_user_new_reg_macro( menu_t **pp, menu_t **dflt );
 char	*menu_user_new_sub(
 	menu_t **pp, menu_t **dflt, bool_t flg_reg_macro
 );
+char	*cb_menu_user_arrange_up( menu_t **pp, menu_t **dflt );
+char	*cb_menu_user_arrange_down( menu_t **pp, menu_t **dflt );
 char	*cb_menu_user_arrange_top( menu_t **pp, menu_t **dflt );
 char	*cb_menu_user_arrange_bottom( menu_t **pp, menu_t **dflt );
 char	*cb_menu_user_remove( menu_t **pp, menu_t **dflt );
 void	set_edit_user_menu( menu_t *ls, menu_call_back_t func, char *ttl );
+char	*cb_menu_user_arrange_up_sel( menu_t **pp, menu_t **dflt );
+char	*cb_menu_user_arrange_down_sel( menu_t **pp, menu_t **dflt );
+char	*arrange_menu_user_1( long n, long d );
 char	*cb_menu_user_arrange_top_sel( menu_t **pp, menu_t **dflt );
 char	*cb_menu_user_arrange_bottom_sel( menu_t **pp, menu_t **dflt );
 char	*cb_menu_user_remove_sel( menu_t **pp, menu_t **dflt );
@@ -180,8 +198,13 @@ char	*cb_menu_replay_sel_load( menu_t **pp, menu_t **dflt );
 char	*cb_menu_wizard( menu_t **pp, menu_t **dflt );
 char	*cb_menu_wizard_on_light( menu_t **pp, menu_t **dflt );
 char	*cb_menu_wizard_off_light( menu_t **pp, menu_t **dflt );
-char	*cb_menu_wizard_add_turn( menu_t **pp, menu_t **dflt );
-char	*cb_menu_wizard_lev_up( menu_t **pp, menu_t **dflt );
+char	*cb_menu_wizard_add_turn_hour( menu_t **pp, menu_t **dflt );
+char	*cb_menu_wizard_add_turn_minute( menu_t **pp, menu_t **dflt );
+char	*cb_menu_wizard_add_turn_turn( menu_t **pp, menu_t **dflt );
+char	*cb_menu_wizard_up_exp( menu_t **pp, menu_t **dflt );
+char	*cb_menu_wizard_up_lev( menu_t **pp, menu_t **dflt );
+char	*cb_menu_wizard_scene( menu_t **pp, menu_t **dflt );
+char	*cb_menu_wizard_last_scene( menu_t **pp, menu_t **dflt );
 char	*cb_menu_out_map_file( menu_t **pp, menu_t **dflt );
 char	*cb_menu_shell( menu_t **pp, menu_t **dflt );
 char	*cb_menu_about_game( menu_t **pp, menu_t **dflt );
