@@ -6,6 +6,7 @@ extern "C" {
 
 int	main( int argc, char **argv );
 void	init_gtk_win( int argc, char **argv );
+void	ena_timer( void );
 void	init_main_sel_conf( GraphConf *cnf );
 void	init_main_win( void );
 void	printMapStatBar( const char *s, ... );
@@ -46,6 +47,12 @@ void	handle_user_menu_clicked(
 void	handle_spell_clicked(
 	GtkWidget *widget, gpointer *data
 );
+void	handle_cancel_clicked(
+	GtkWidget *widget, gpointer *data
+);
+void	handle_ok_clicked(
+	GtkWidget *widget, gpointer *data
+);
 gint	handle_map_button_press(
 	GtkWidget *widget, GdkEventMotion *event
 );
@@ -55,16 +62,6 @@ gint	handle_map_button_release(
 gint	handle_map_scroll(
 	GtkWidget *widget, GdkEventScroll *event
 );
-void	showWin(
-	GtkWidget *mMenuWin,
-	gint *nPreX, gint *nPreY,
-	gint *nPreW, gint *nPreH
-);
-void	wipeWin(
-	GtkWidget *mMenuWin,
-	gint *nPreX, gint *nPreY,
-	gint *nPreW, gint *nPreH
-);
 
 #ifdef __cplusplus
 }
