@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: main-gtk.cpp,v 1.51 2008/09/22 07:51:26 bowkenken Exp $
+* $Id: main-gtk.cpp,v 1.58 2008/10/06 23:03:53 bowkenken Exp $
 ***************************************************************/
 
 ////////////////////////////////////////////////////////////////
@@ -131,7 +131,10 @@ void	init_gtk_win( int argc, char **argv )
 
 	init_main_win();
 
+	// SDL 
+
 	gMusic.init();
+	gJoystick.init();
 
 	// ޡ
 
@@ -155,7 +158,7 @@ void	init_gtk_win( int argc, char **argv )
 
 void	ena_timer( void )
 {
-	ghTimer = gtk_timeout_add( 1000 * 4 / 60,
+	ghTimer = gtk_timeout_add( 1000 * TIMER_FRAME / 60,
 			handle_map_draw,
 			(gpointer)gMapDrawingArea );
 }
@@ -171,7 +174,6 @@ void	init_main_sel_conf( GraphConf *cnf )
 	gPcgDun.init( cnf );
 	configure_map();
 
-//@@@	gtk_timeout_remove( ghTimer );
 	change_scene( SCENE_N_TOWN );
 
 	gGuiMenu.init();
@@ -180,6 +182,14 @@ void	init_main_sel_conf( GraphConf *cnf )
 	gKey.init();
 	initMouseMotionFunc();
 
+	pos_t *draw = get_map_draw_pos();
+	pos_t *draw_gui = get_map_draw_pos_gui();
+	if( (draw != NULL) && (draw_gui != NULL) ){
+		draw_gui->x = draw->x;
+		draw_gui->y = draw->y;
+		gPcgDun.scrollTile( draw_gui->x, draw_gui->y );
+	}
+
 	gPcgDun.redraw();
 
 	if( !call_game_thread_create( main_thread ) )
@@ -654,6 +664,12 @@ void	handle_map_scroll_changed(
 	long w = (long)hAdj->page_size;
 	long h = (long)vAdj->page_size;
 
+	pos_t *draw_gui = get_map_draw_pos_gui();
+	if( draw_gui != NULL ){
+		draw_gui->x = x / gPcgDun.getTileSizeX( true );
+		draw_gui->y = y / gPcgDun.getTileSizeY( true );
+	}
+
 	gPcgDun.drawScroll( x, y, w, h );
 }
 
@@ -665,6 +681,8 @@ void	handle_map_scroll_changed(
 
 gint	handle_map_draw( gpointer p )
 {
+	gJoystick.checkEvent();
+
 #if 0
 //@@@
 	GtkWidget *drawingArea = (GtkWidget *)p;
@@ -688,7 +706,10 @@ gint	handle_map_draw( gpointer p )
 			0, 0,
 			w, h );
 #else
-	if( chk_scene_group( SCENE_GROUP_N_TITLE ) ){
+	if( get_scene() == SCENE_N_LAST_BOSS ){
+		if( !gPcgDun.drawLastBoss() )
+			return TRUE;
+	} else if( chk_scene_group( SCENE_GROUP_N_TITLE ) ){
 		gPcgDun.drawTitle();
 	} else if( chk_scene_group( SCENE_GROUP_N_ENDING ) ){
 		gPcgDun.drawEnding();
