@@ -106,6 +106,8 @@ char	*cb_menu_move( menu_t **pp, menu_t **dflt );
 char	*cb_menu_fight( menu_t **pp, menu_t **dflt );
 char	*cb_menu_load_wiz( menu_t **pp, menu_t **dflt );
 char	*cb_menu_save_wiz( menu_t **pp, menu_t **dflt );
+void	menu_load_wiz( void );
+void	menu_save_wiz( void );
 bool_t	menu_load( bool_t flg_txt );
 bool_t	menu_save( bool_t flg_txt );
 bool_t	menu_save_n( bool_t flg_txt, long save_n );
